@@ -1,7 +1,9 @@
 from django import template
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.http import urlencode
 
+from wafer.registration import views
+
 register = template.Library()
 
 
@@ -11,7 +13,7 @@ def wafer_sso_url(context, sso_method):
     Return the correct URL to SSO with the given method.
     '''
     request = context.request
-    url = reverse('wafer.registration.views.%s_login' % sso_method)
+    url = reverse(getattr(views, '%s_login' % sso_method))
     if 'next' in request.GET:
         url += '?' + urlencode({'next': request.GET['next']})
     return url
