@@ -1,15 +1,20 @@
-import json
 import datetime as D
-import icalendar
+import json
+import os.path
+from io import BytesIO
 from xml.etree import ElementTree
 
 from django.test import Client, TestCase
-from django.contrib.auth import get_user_model
-from django.utils import timezone
+from django.utils import http, timezone
+
+import icalendar
+import lxml.etree
 
-from wafer.talks.models import Talk, ACCEPTED
 from wafer.pages.models import Page
 from wafer.schedule.models import ScheduleBlock, Venue, Slot, ScheduleItem
+from wafer.talks.models import ACCEPTED
+from wafer.talks.tests.fixtures import create_talk
+from wafer.tests.utils import create_user
 from wafer.utils import QueryTracker
 
 
@@ -59,13 +64,8 @@ def make_slot():
 def create_client(username=None, superuser=False):
     client = Client()
     if username:
-        email = '%s@example.com' % (username,)
+        create_user(username, superuser=superuser)
         password = '%s_password' % (username,)
-        if superuser:
-            create = get_user_model().objects.create_superuser
-        else:
-            create = get_user_model().objects.create_user
-        create(username, email, password)
         client.login(username=username, password=password)
     return client
 
@@ -125,6 +125,8 @@ class ScheduleViewTests(TestCase):
             response = c.get('/schedule/')
             self.assertTrue(len(tracker.queries) < 60)
 
+        self.assertIn('Last-Modified', response)
+
         [day1] = response.context['schedule_pages']
 
         assert len(day1.rows) == 3
@@ -1045,9 +1047,7 @@ class CurrentViewTests(TestCase):
             item.slots.add(slots[index // 2])
 
         c = Client()
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur1.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur1.isoformat()})
         context = response.context
 
         assert context['cur_slot'] == slots[0]
@@ -1057,9 +1057,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][0].items[venue1]['note'] == 'current'
         assert context['slots'][1].items[venue1]['note'] == 'forthcoming'
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur2.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur2.isoformat()})
         context = response.context
         assert context['cur_slot'] == slots[1]
         assert len(context['schedule_page'].venues) == 2
@@ -1069,9 +1067,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][1].items[venue1]['note'] == 'current'
         assert context['slots'][2].items[venue1]['note'] == 'forthcoming'
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur3.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur3.isoformat()})
         context = response.context
         assert context['cur_slot'] == slots[2]
         assert len(context['schedule_page'].venues) == 2
@@ -1081,9 +1077,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][1].items[venue1]['note'] == 'current'
         assert context['slots'][2].items[venue1]['note'] == 'forthcoming'
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur4.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur4.isoformat()})
         context = response.context
         assert context['cur_slot'] == slots[3]
         assert len(context['schedule_page'].venues) == 2
@@ -1092,9 +1086,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][0].items[venue1]['note'] == 'complete'
         assert context['slots'][1].items[venue1]['note'] == 'current'
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur5.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur5.isoformat()})
         context = response.context
         assert context['cur_slot'] is None
         assert len(context['schedule_page'].venues) == 2
@@ -1104,8 +1096,7 @@ class CurrentViewTests(TestCase):
 
         # Check that next day is an empty current view
         response = c.get('/schedule/current/',
-                         {'day': day2.start_time.strftime('%Y-%m-%d'),
-                          'time': cur3.strftime('%H:%M')})
+            {'timestamp': (cur3 + D.timedelta(days=1)).isoformat()})
         assert len(response.context['slots']) == 0
 
     def test_current_view_complex(self):
@@ -1172,9 +1163,7 @@ class CurrentViewTests(TestCase):
         cur4 = D.datetime(2013, 9, 22, 14, 30, 0, tzinfo=timezone.utc)
 
         c = Client()
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur1.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur1.isoformat()})
         context = response.context
         assert context['cur_slot'] == slot1
         assert len(context['schedule_page'].venues) == 3
@@ -1183,9 +1172,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][0].items[venue1]['colspan'] == 1
         assert context['slots'][0].items[venue2]['item'] is None
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur2.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur2.isoformat()})
         context = response.context
         assert context['cur_slot'] == slot2
         assert len(context['slots']) == 3
@@ -1198,9 +1185,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][2].items[venue2]['note'] == 'forthcoming'
         assert context['slots'][2].items[venue2]['rowspan'] == 1
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur3.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur3.isoformat()})
         context = response.context
         assert context['cur_slot'] == slot3
         assert len(context['slots']) == 3
@@ -1211,9 +1196,7 @@ class CurrentViewTests(TestCase):
         assert context['slots'][1].items[venue2]['note'] == 'current'
         assert context['slots'][1].items[venue2]['rowspan'] == 2
 
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur4.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur4.isoformat()})
         context = response.context
         assert context['cur_slot'] == slot5
         assert len(context['slots']) == 2
@@ -1270,12 +1253,12 @@ class CurrentViewTests(TestCase):
         items[9].slots.add(slot5)
 
         # During the first slot
-        cur1 = D.time(10, 30, 0)
+        cur1 = D.datetime(2013, 9, 22, 10, 30, 0)
         # Middle of the day
-        cur2 = D.time(11, 30, 0)
-        cur3 = D.time(12, 30, 0)
+        cur2 = D.datetime(2013, 9, 22, 11, 30, 0)
+        cur3 = D.datetime(2013, 9, 22, 12, 30, 0)
         # During the last slot
-        cur4 = D.time(14, 30, 0)
+        cur4 = D.datetime(2013, 9, 22, 14, 30, 0)
 
         def validate_current(response):
             """Validate that the current view is still has the expected content"""
@@ -1293,23 +1276,19 @@ class CurrentViewTests(TestCase):
 
         c = Client()
         # Check that we don't highlight if not asked
-        response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur2.strftime('%H:%M')})
+        response = c.get('/schedule/current/', {'timestamp': cur2.isoformat()})
         validate_current(response)
         self.assertNotContains(response, b'schedule-highlight-venue')
         # Check with invalid venue
         response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur2.strftime('%H:%M'),
+                         {'timestamp': cur2.isoformat(),
                           'highlight-venue': 'aaaa'})
         validate_current(response)
         self.assertNotContains(response, b'schedule-highlight-venue')
 
         # Check with venue 1
         response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur2.strftime('%H:%M'),
+                         {'timestamp': cur2.isoformat(),
                           'highlight-venue': '%d' % venue1.pk})
         validate_current(response)
         self.assertContains(response, b'schedule-highlight-venue')
@@ -1357,8 +1336,7 @@ class CurrentViewTests(TestCase):
 
         # Check with venue 3
         response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur2.strftime('%H:%M'),
+                         {'timestamp': cur2.isoformat(),
                           'highlight-venue': '%d' % venue3.pk})
         validate_current(response)
         self.assertContains(response, b'schedule-highlight-venue')
@@ -1423,10 +1401,7 @@ class CurrentViewTests(TestCase):
         slot1 = Slot.objects.create(start_time=start1, end_time=start2)
         slot2 = Slot.objects.create(start_time=start1, end_time=end)
 
-        user = get_user_model().objects.create_user('john', 'best@wafer.test',
-                                                    'johnpassword')
-        talk = Talk.objects.create(title="Test talk", status=ACCEPTED,
-                                   corresponding_author_id=user.id)
+        talk = create_talk('Test talk', status=ACCEPTED, username='john')
 
         item1 = ScheduleItem.objects.create(venue=venue1,
                                             talk_id=talk.pk)
@@ -1437,8 +1412,7 @@ class CurrentViewTests(TestCase):
 
         c = Client()
         response = c.get('/schedule/current/',
-                         {'day': day1.start_time.strftime('%Y-%m-%d'),
-                          'time': cur1.strftime('%H:%M')})
+                         {'timestamp': cur1.isoformat()})
         assert response.context['active'] is False
 
 
@@ -1463,6 +1437,7 @@ class NonHTMLViewTests(TestCase):
         venue2 = Venue.objects.create(order=2, name='Venue 2')
         venue1.blocks.add(day1)
         venue2.blocks.add(day1)
+        venue1.blocks.add(day2)
 
         start1 = D.datetime(2013, 9, 22, 10, 0, 0, tzinfo=timezone.utc)
         start2 = D.datetime(2013, 9, 22, 11, 0, 0, tzinfo=timezone.utc)
@@ -1487,27 +1462,34 @@ class NonHTMLViewTests(TestCase):
         for index, item in enumerate(items):
             item.slots.add(slots[index // 2])
 
+        talk = create_talk('Test talk', status=ACCEPTED, username='john')
+        talk_item = ScheduleItem.objects.create(venue=venue1, talk_id=talk.pk)
+        talk_item.slots.add(slots[4])
+
     def test_pentabarf_view(self):
         # We don't exhaustively test that the pentabarf view is valid pentabarf,
         # instead we test that the XML is valid, and that we
         # have the basic details we expect present
         c = Client()
         response = c.get('/schedule/pentabarf.xml')
+        self.assertIn('Last-Modified', response)
         parsed = ElementTree.XML(response.content)
         self.assertEqual(parsed.tag, 'schedule')
-        self.assertEqual(parsed[0].tag, 'conference')
-        self.assertEqual(parsed[1].tag, 'day')
+        self.assertEqual(parsed[0].tag, 'generator')
+        self.assertEqual(parsed[1].tag, 'version')
+        self.assertEqual(parsed[2].tag, 'conference')
+        self.assertEqual(parsed[3].tag, 'day')
 
         # Various tools expect 'start' and 'end' values, so
         # check we have those
-        conf = parsed[0]
+        conf = parsed[2]
         self.assertEqual('title', conf[0].tag)
         self.assertEqual('start', conf[1].tag)
         self.assertEqual('end', conf[2].tag)
         self.assertEqual('2013-09-22', conf[1].text)
         self.assertEqual('2013-09-23', conf[2].text)
 
-        day = parsed[1]
+        day = parsed[3]
         self.assertIn(('date', '2013-09-22'), day.items())
         self.assertEqual(day[0].tag, 'room')
         self.assertIn(('name', 'Venue 1'), day[0].items())
@@ -1517,6 +1499,15 @@ class NonHTMLViewTests(TestCase):
         title = [z for z in talk if z.tag == 'title'][0]
         self.assertEqual(title.text, 'Item 0')
 
+    def test_pentabarf_view_against_frab_xsd(self):
+        # Frab has an XSD schema, validate against it
+        doc = lxml.etree.parse(os.path.dirname(__file__) + '/frab.xml.xsd')
+        xsd = lxml.etree.XMLSchema(doc)
+        c = Client()
+        response = c.get('/schedule/pentabarf.xml')
+        doc = lxml.etree.parse(BytesIO(response.content))
+        xsd.assertValid(doc)
+
     def test_ics_view(self):
         # This is a bit circular, since we use icalendar to generate
         # the data, but does test we can at least parse the generated
@@ -1524,11 +1515,12 @@ class NonHTMLViewTests(TestCase):
         # and some of the required details
         c = Client()
         response = c.get('/schedule/schedule.ics')
+        self.assertIn('Last-Modified', response)
         calendar = icalendar.Calendar.from_ical(response.content)
         # No major errors
         self.assertFalse(calendar.is_broken)
         # Check number of events
-        self.assertEqual(len(calendar.walk(name='VEVENT')), 8)
+        self.assertEqual(len(calendar.walk(name='VEVENT')), 9)
         # Check we have the right time in places
         event = calendar.walk(name='VEVENT')[0]
         self.assertEqual(event['dtstart'].params['value'], 'DATE-TIME')
@@ -1536,6 +1528,31 @@ class NonHTMLViewTests(TestCase):
         # Check that we have the page slug in the ical event
         self.assertTrue('/test0/' in event['url'])
 
+    def test_xml_conditional_requests(self):
+        # All the public schedule views implement these, but we'll just check
+        # one of them
+        c = Client()
+        response = c.get('/schedule/pentabarf.xml')
+        self.assertEqual(response.status_code, 200)
+        last_modified = response['Last-Modified']
+
+        with QueryTracker() as tracker:
+            not_modified_response = c.get(
+                '/schedule/pentabarf.xml', HTTP_IF_MODIFIED_SINCE=last_modified)
+        self.assertEqual(not_modified_response.status_code, 304)
+        self.assertLess(len(tracker.queries), 2)
+
+        last_modified_seconds = http.parse_http_date(last_modified)
+        last_modified_seconds -= 1
+        before_last_modified = http.http_date(last_modified_seconds)
+
+        with QueryTracker() as tracker:
+            modified_response = c.get(
+                '/schedule/pentabarf.xml',
+                HTTP_IF_MODIFIED_SINCE=before_last_modified)
+        self.assertEqual(modified_response.status_code, 200)
+        self.assertGreater(len(tracker.queries), 10)
+
 
 class JsonViewTests(TestCase):
 
@@ -1579,16 +1596,8 @@ class JsonViewTests(TestCase):
         for index, item in enumerate(items):
             item.slots.add(slots[(index + 1) // 2])
 
-        user = get_user_model().objects.create_user('jimbob', 'best@wafer.test',
-                                                    'johnpassword')
-
-        talk1 = Talk.objects.create(title="Test talk", status=ACCEPTED,
-                                    corresponding_author_id=user.id)
-        talk1.authors.add(user)
-
-        talk2 = Talk.objects.create(title="Test 2 talk", status=ACCEPTED,
-                                    corresponding_author_id=user.id)
-        talk2.authors.add(user)
+        talk1 = create_talk('Test talk', status=ACCEPTED, username='jimbob')
+        talk2 = create_talk('Test 2 talk', status=ACCEPTED, username='jimbob2')
 
         item1 = ScheduleItem.objects.create(venue=venue1,
                                             talk_id=talk1.pk)
