@@ -1,6 +1,6 @@
 import os
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 # Django settings for wafer project.
 
@@ -106,6 +106,7 @@ TEMPLATES = [
                 'django.template.context_processors.debug',
                 'django.template.context_processors.i18n',
                 'django.template.context_processors.media',
+                'django.template.context_processors.request',
                 'django.template.context_processors.static',
                 'django.template.context_processors.tz',
                 'django.contrib.messages.context_processors.messages',
@@ -147,7 +148,6 @@ INSTALLED_APPS = (
     'reversion',
     'bakery',
     'crispy_forms',
-    'django_nose',
     'rest_framework',
     'django_select2',
     'wafer',
@@ -166,8 +166,6 @@ INSTALLED_APPS = (
     'django.contrib.admin',
 )
 
-TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
-
 # A sample logging configuration. The only tangible logging
 # performed by this configuration is to send an email to
 # the site admins on every HTTP 500 error when DEBUG=False.
