@@ -28,7 +28,7 @@ class MarkdownTextField(TextField):
         self._markdown_safe = not kwargs.pop('allow_html', True)
         self._add_html_field = kwargs.pop('add_html_field', True)
         self._html_field_suffix = kwargs.pop('html_field_suffix', '_html')
-        super(MarkdownTextField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def contribute_to_class(self, cls, name):
         # During migrations, the column will already be in the new schema,
@@ -37,7 +37,7 @@ class MarkdownTextField(TextField):
         if self._add_html_field:
             self._html_field = "%s%s" % (name, self._html_field_suffix)
             TextField(editable=False).contribute_to_class(cls, self._html_field)
-        super(MarkdownTextField, self).contribute_to_class(cls, name)
+        super().contribute_to_class(cls, name)
 
     def pre_save(self, model_instance, add):
         value = getattr(model_instance, self.attname)
@@ -49,7 +49,7 @@ class MarkdownTextField(TextField):
 
     def deconstruct(self):
         # Django 1.7 migration serializer
-        name, path, args, kwargs = super(MarkdownTextField, self).deconstruct()
+        name, path, args, kwargs = super().deconstruct()
         kwargs['add_html_field'] = False
         kwargs['allow_html'] = self._markdown_safe
         kwargs['html_field_suffix'] = self._html_field_suffix
