@@ -1,4 +1,4 @@
-from django.conf.urls import url, include
+from django.urls import re_path, include
 from rest_framework import routers
 
 from wafer.sponsors.views import (
@@ -10,10 +10,10 @@ router.register(r'sponsors', SponsorViewSet)
 router.register(r'packages', PackageViewSet)
 
 urlpatterns = [
-    url(r'^$', ShowSponsors.as_view(),
+    re_path(r'^$', ShowSponsors.as_view(),
         name='wafer_sponsors'),
-    url(r'^(?P<pk>\d+)/$', SponsorView.as_view(), name='wafer_sponsor'),
-    url(r'^packages/$', ShowPackages.as_view(),
+    re_path(r'^(?P<pk>\d+)/$', SponsorView.as_view(), name='wafer_sponsor'),
+    re_path(r'^packages/$', ShowPackages.as_view(),
         name='wafer_sponsorship_packages'),
-    url(r'^api/', include(router.urls)),
+    re_path(r'^api/', include(router.urls)),
 ]
