@@ -6,36 +6,11 @@ from django.test import Client, TestCase
 from django.urls import reverse
 
 from wafer.tests.api_utils import SortedResultsClient
-from wafer.tests.utils import create_user
+from wafer.tests.utils import create_user, mock_avatar_url
 from wafer.talks.models import (
-    Talk, TalkUrl, TalkType, ACCEPTED, REJECTED, SUBMITTED,
-    UNDER_CONSIDERATION, CANCELLED, PROVISIONAL)
-
-
-def create_talk_type(name):
-    """Create a talk type"""
-    return TalkType.objects.create(name=name)
-
-
-
-def create_talk(title, status, username, talk_type=None):
-    user = create_user(username)
-    talk = Talk.objects.create(
-        title=title, status=status, corresponding_author_id=user.id)
-    talk.authors.add(user)
-    talk.notes = "Some notes for talk %s" % title
-    talk.private_notes = "Some private notes for talk %s" % title
-    talk.save()
-    if talk_type:
-        talk.talk_type = talk_type
-        talk.save()
-    return talk
-
-
-def mock_avatar_url(self):
-    if self.user.email is None:
-        return None
-    return "avatar-%s" % self.user.email
+    Talk, TalkUrl, ACCEPTED, REJECTED, SUBMITTED, UNDER_CONSIDERATION,
+    CANCELLED, PROVISIONAL)
+from wafer.talks.tests.fixtures import create_talk, create_talk_type
 
 
 class UsersTalksTests(TestCase):
@@ -434,9 +409,12 @@ class SpeakerTests(TestCase):
     @mock.patch('wafer.users.models.UserProfile.avatar_url', mock_avatar_url)
     def test_multiple_types(self):
         """Test the view for multiple talk types"""
-        talk_d = create_talk('Talk D', ACCEPTED, 'author_d', self.talk_type1)
-        talk_e = create_talk('Talk E', ACCEPTED, 'author_e', self.talk_type1)
-        keynote_f = create_talk('Talk F', ACCEPTED, 'author_f', self.talk_type2)
+        talk_d = create_talk('Talk D', ACCEPTED, 'author_d',
+                             talk_type=self.talk_type1)
+        talk_e = create_talk('Talk E', ACCEPTED, 'author_e',
+                             talk_type=self.talk_type1)
+        keynote_f = create_talk('Talk F', ACCEPTED, 'author_f',
+                                talk_type=self.talk_type2)
 
         user_d = talk_d.corresponding_author
         user_e = talk_e.corresponding_author
@@ -531,10 +509,11 @@ class SpeakerTests(TestCase):
             '</div>',
         ]), html=True)
 
+    @mock.patch('wafer.users.models.UserProfile.avatar_url', mock_avatar_url)
     def test_exluding_types(self):
         """Test that the show_speakers flag excludes the speakers from the list."""
         hidden = create_talk_type('Hidden')
-        talk_d = create_talk('Talk D', ACCEPTED, 'author_d', hidden)
+        talk_d = create_talk('Talk D', ACCEPTED, 'author_d', talk_type=hidden)
 
         response = self.client.get(
             reverse('wafer_talks_speakers'))
@@ -550,6 +529,7 @@ class SpeakerTests(TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertNotIn('Hidden', response.context["speaker_rows"])
 
+    @mock.patch('wafer.users.models.UserProfile.avatar_url', mock_avatar_url)
     def test_ordering_types(self):
         """Test that we order the speakers according to the talk type correctly"""
         test1 = create_talk_type('Test 1')
@@ -561,8 +541,8 @@ class SpeakerTests(TestCase):
         test2.order = 2
         test2.save()
 
-        talk_d = create_talk('Talk D', ACCEPTED, 'author_d', test1)
-        talk_e = create_talk('Talk D', ACCEPTED, 'author_e', test2)
+        talk_d = create_talk('Talk D', ACCEPTED, 'author_d', talk_type=test1)
+        talk_e = create_talk('Talk D', ACCEPTED, 'author_e', talk_type=test2)
         response = self.client.get(
             reverse('wafer_talks_speakers'))
         types = list(response.context['speaker_rows'])
