@@ -12,10 +12,7 @@ from django.views.decorators.http import require_POST
 from django.views.generic.edit import FormView
 
 from rest_framework import viewsets
-from rest_framework.permissions import (
-    DjangoModelPermissions,
-    DjangoModelPermissionsOrAnonReadOnly,
-)
+from rest_framework.permissions import DjangoModelPermissions
 from rest_framework_extensions.mixins import NestedViewSetMixin
 
 from wafer.tickets.models import Ticket, TicketType
@@ -30,7 +27,7 @@ class ClaimView(LoginRequiredMixin, FormView):
     form_class = TicketForm
 
     def get_context_data(self, **kwargs):
-        context = super(ClaimView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context['can_claim'] = self.can_claim()
         return context
 
@@ -47,7 +44,7 @@ class ClaimView(LoginRequiredMixin, FormView):
         ticket = Ticket.objects.get(barcode=form.cleaned_data['barcode'])
         ticket.user = self.request.user
         ticket.save()
-        return super(ClaimView, self).form_valid(form)
+        return super().form_valid(form)
 
     def get_success_url(self):
         return reverse(
