@@ -1,4 +1,4 @@
-from django.conf.urls import include, url
+from django.urls import include, re_path
 from rest_framework import routers
 
 from wafer.users.views import (UsersView, ProfileView, EditProfileView,
@@ -9,16 +9,16 @@ router = routers.DefaultRouter()
 router.register(r'users', UserViewSet)
 
 urlpatterns = [
-    url(r'^$', UsersView.as_view(),
+    re_path(r'^$', UsersView.as_view(),
         name='wafer_users'),
-    url(r'^api/', include(router.urls)),
-    url(r'^page/(?P<page>\d+)/$', UsersView.as_view(),
+    re_path(r'^api/', include(router.urls)),
+    re_path(r'^page/(?P<page>\d+)/$', UsersView.as_view(),
         name='wafer_users_page'),
-    url(r'^(?P<username>[\w.@+-]+)/$', ProfileView.as_view(),
+    re_path(r'^(?P<username>[\w.@+-]+)/$', ProfileView.as_view(),
         name='wafer_user_profile'),
-    url(r'^(?P<username>[\w.@+-]+)/edit/$', EditUserView.as_view(),
+    re_path(r'^(?P<username>[\w.@+-]+)/edit/$', EditUserView.as_view(),
         name='wafer_user_edit'),
-    url(r'^(?P<username>[\w.@+-]+)/edit_profile/$',
+    re_path(r'^(?P<username>[\w.@+-]+)/edit_profile/$',
         EditProfileView.as_view(),
         name='wafer_user_edit_profile'),
 ]
